@@ -4,11 +4,11 @@
  * GChemPaint library
  * text.h
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -53,6 +53,14 @@ Constructs a new empty text positioned according to the given coordiantes
 */
 	Text (double x, double y);
 /*!
+@param tag a gccv::Tag to apply to the whole text.
+@param x the x coordinate.
+@param y the y coordinate.
+
+Constructs a new empty text positioned according to the given coordiantes
+*/
+	Text (gccv::Tag tag, double x, double y);
+/*!
 The destructor.
 */
 	virtual ~Text ();
@@ -206,11 +214,17 @@ a carbon atom symbol using the current document theme.
 /*!\fn GetAnchor()
 @return the gccv::Anchor used for the text.
 */
-/*!fn GetRefAnchor()
+	/*!fn GetRefAnchor()
 @return the gccv::Anchor used for the text as a reference.
 */
 GCU_PROP (gccv::Anchor, Anchor)
 
+/*!\fn GetGlobalTag()
+@return the global gccv::TextTag applied to this text or gccv::Invalid if none
+has been explicitly set in the constructor.
+*/
+GCU_RO_PROP (gccv::Tag, GlobalTag)
+
 private:
 	double m_Interline;
 	GtkJustification m_Justification;
